@@ -1,11 +1,11 @@
 .onAttach <- function(libname, pkgname) {
 	#assign(".oldContrasts", options("contrasts"), envir = .GlobalEnv)
-  packageStartupMessage("************\nWelcome to afex created by Henrik Singmann. Important notes:\n")
+  packageStartupMessage("************\nWelcome to afex. Important notes:\n")
 	if (options("contrasts")[[1]][1] != "contr.sum") {
 		packageStartupMessage("Setting contrasts to effects coding: options(contrasts=c('contr.sum', 'contr.poly'))\nThis affects all functions using contrasts (e.g., lmer, lm, aov, ...).\nTo reset default settings run: options(contrasts=c('contr.treatment', 'contr.poly')) (all afex functions should be unaffected by this)\n")
     # \nPrevious contrasts saved in '.oldContrasts'.
 		options(contrasts=c('contr.sum', 'contr.poly'))
 	} else packageStartupMessage("Contrasts already set to effects coding: options(contrasts=c('contr.sum', '...'))\n")
-  packageStartupMessage("afex loads the required packages (e.g., lme4, coin, car, pbkrtest) in an order that does not lead to problems.\nLoading any of the packages (specifically lme4) beforehand usually leads to problems.\nLoading nlme in addition to afex (before or after loading it), also leads to problems.\n************")
+  packageStartupMessage("afex loads the required packages (e.g., lme4, car, pbkrtest) in an order that should not lead to problems.\nLoading any of the packages (specifically lme4) beforehand can lead to problems (especially with older versions of either).\nLoading nlme in addition to afex (before or after loading it), may especially lead to problems.\n************")
 }
 
